From: Zheng Junjie via Guix-patches via <guix-patches@gnu.org>
To: 75051@debbugs.gnu.org
Subject: [bug#75051] [PATCH 07/14] gnu: readline: Fix cross-compiling to loongarch64.
Date: Tue, 24 Dec 2024 01:12:50 +0800 [thread overview]
Message-ID: <tencent_49ACC23F259DD472A492C75A874DB254F707@qq.com> (raw)
In-Reply-To: <cover.1734972657.git.873216071@qq.com>
* gnu/packages/readline.scm (readline)[arguments]: When cross-compiling to
loongarch64, Add update-config-scripts phase.
[native-inputs]: When cross-compiling to loongarch64, Add config.
Change-Id: Ie369d53c7f2493a7a65fe592a3671719dee264c0
---
gnu/packages/readline.scm | 61 +++++++++++++++++++++++++--------------
1 file changed, 40 insertions(+), 21 deletions(-)
diff --git a/gnu/packages/readline.scm b/gnu/packages/readline.scm
index 8200a24f1a1..c19c7326497 100644
--- a/gnu/packages/readline.scm
+++ b/gnu/packages/readline.scm
@@ -82,29 +82,48 @@ (define-public readline
(build-system gnu-build-system)
(propagated-inputs (list ncurses))
(arguments
- (list #:configure-flags
- #~(list (string-append
- "LDFLAGS=-Wl,-rpath -Wl,"
- (dirname (search-input-file %build-inputs
- "lib/libncurses.so")))
+ (append
+ (if (and (target-loongarch64?)
+ (%current-target-system))
+ (list #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'update-config-scripts
+ (lambda* (#:key inputs native-inputs #:allow-other-keys)
+ ;; Replace outdated config.guess and config.sub.
+ (for-each (lambda (file)
+ (install-file
+ (search-input-file
+ (or native-inputs inputs)
+ (string-append "/bin/" file)) "./support"))
+ '("config.guess" "config.sub"))))))
+ '())
+ (list #:configure-flags
+ #~(list (string-append
+ "LDFLAGS=-Wl,-rpath -Wl,"
+ (dirname (search-input-file %build-inputs
+ "lib/libncurses.so")))
- ;; This test does an 'AC_TRY_RUN', which aborts when
- ;; cross-compiling, so provide the correct answer.
- #$@(if (%current-target-system)
- '("bash_cv_wcwidth_broken=no")
- '())
- ;; MinGW: ncurses provides the termcap api.
- #$@(if (target-mingw?)
- '("bash_cv_termcap_lib=ncurses")
- '()))
+ ;; This test does an 'AC_TRY_RUN', which aborts when
+ ;; cross-compiling, so provide the correct answer.
+ #$@(if (%current-target-system)
+ '("bash_cv_wcwidth_broken=no")
+ '())
+ ;; MinGW: ncurses provides the termcap api.
+ #$@(if (target-mingw?)
+ '("bash_cv_termcap_lib=ncurses")
+ '()))
- #:make-flags
- (if (target-mingw?)
- ;; MinGW: termcap in ncurses
- ;; some SIG_* #defined in _POSIX
- #~'("TERMCAP_LIB=-lncurses"
- "CPPFLAGS=-D_POSIX -D'chown(f,o,g)=0'")
- #~'())))
+ #:make-flags
+ (if (target-mingw?)
+ ;; MinGW: termcap in ncurses
+ ;; some SIG_* #defined in _POSIX
+ #~'("TERMCAP_LIB=-lncurses"
+ "CPPFLAGS=-D_POSIX -D'chown(f,o,g)=0'")
+ #~'()))))
+ (native-inputs (if (and (target-loongarch64?)
+ (%current-target-system))
+ (list config)
+ '()))
(synopsis "Edit command lines while typing, with history support")
(description
"The GNU readline library allows users to edit command lines as they
--
2.46.0
next prev parent reply other threads:[~2024-12-23 17:14 UTC|newest]
Thread overview: 14+ messages / expand[flat|nested] mbox.gz Atom feed top
[not found] <cover.1734972657.git.873216071@qq.com>
2024-12-23 17:05 ` [bug#75051] [PATCH 01/14] guix: Add loongarch platform Zheng Junjie via Guix-patches via
2024-12-23 17:08 ` [bug#75051] [PATCH 02/14] utils: Add target-loongarch64? Zheng Junjie via Guix-patches via
2024-12-23 17:08 ` [bug#75051] [PATCH 03/14] gnu: Add linux-libre-headers-5.19.17 Zheng Junjie via Guix-patches via
2024-12-23 17:10 ` [bug#75051] [PATCH 04/14] gnu: cross-base: Add cross-compiling support for loongarch64 Zheng Junjie via Guix-patches via
2024-12-23 17:11 ` [bug#75051] [PATCH 05/14] gnu: %glibc-stripped: Fix cross-compiling to loongarch64 Zheng Junjie via Guix-patches via
2024-12-23 17:12 ` [bug#75051] [PATCH 06/14] gnu: openssl: Support loongarch64 Zheng Junjie via Guix-patches via
2024-12-23 17:12 ` Zheng Junjie via Guix-patches via [this message]
2024-12-23 17:13 ` [bug#75051] [PATCH 08/14] gnu: gdbm: Fix cross-compiling to loongarch64 Zheng Junjie via Guix-patches via
2024-12-23 17:13 ` [bug#75051] [PATCH 09/14] gnu: libatomic-ops: " Zheng Junjie via Guix-patches via
2024-12-23 17:13 ` [bug#75051] [PATCH 10/14] gnu: bash: " Zheng Junjie via Guix-patches via
2024-12-23 17:13 ` [bug#75051] [PATCH 11/14] gnu: sed: " Zheng Junjie via Guix-patches via
2024-12-23 17:13 ` [bug#75051] [PATCH 12/14] gnu: isl: " Zheng Junjie via Guix-patches via
2024-12-23 17:13 ` [bug#75051] [PATCH 13/14] gnu: pcre2: disable jit on loongarch64 Zheng Junjie via Guix-patches via
2024-12-23 17:14 ` [bug#75051] [PATCH 14/14] gnu: elfutils: Fix cross-compiling to loongarch64 Zheng Junjie via Guix-patches via
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tencent_49ACC23F259DD472A492C75A874DB254F707@qq.com \
--to=guix-patches@gnu.org \
--cc=75051@debbugs.gnu.org \
--cc=873216071@qq.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this external index
https://git.savannah.gnu.org/cgit/guix.git
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.